Learn R Programming

ctsfeatures (version 1.2.2)

calculate_motifs: Computes the relative frequency of motifs in a categorical time series

Description

calculate_motifs computes the motifs of a categorical time series

Usage

calculate_motifs(series, motif_length)

Value

Returns an array with the relative frequency of motifs in a categorical time series.

Arguments

series

An object of type tsibble (see R package tsibble), whose column named Value contains the values of the corresponding CTS. This column must be of class factor and its levels must be determined by the range of the CTS.

motif_length

The length of the motif.

Author

Ángel López-Oriona, José A. Vilar

Details

Given a CTS of length \(T\) with range \(\mathcal{V}=\{1, 2, \ldots, r\}\), \(\overline{X}_t=\{\overline{X}_1,\ldots, \overline{X}_T\}\), and a motif length \(L\), the function returns an array of \(r^L\) elements, with the element in the position \((i_1, i_2, \ldots, i_r)\) being the relative frequency of the motif ``\(i_1i_2 \cdots i_r\)'' in the corresponding time series.

References

lonardi2002findingctsfeatures

Examples

Run this code
sequence_1 <- GeneticSequences[which(GeneticSequences$Series==1),]
calculate_motifs(sequence_1, motif_length = 3)
# Computing the relative frequencies of motifs of length 3 for the first
# series in dataset GeneticSequences

Run the code above in your browser using DataLab